==> phpwiki_1.3.7.orig.tar.gz: phpwiki-1.3.7/locale/sv/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%s at %s"] =
   "%s i %s";
$locale["%s days"] =
   "%s dar";
$locale["%s of this page"] =
   "%s fr den hr sidan";
$locale["%s: %s"] =
   "%s: %s";
$locale["%s: file not found"] =
   "%s: fila ingen funna";
$locale["(diff)"] =
   "(diff)";
$locale["1 day"] =
   "1 dag";
$locale["<no matches>"] =
   "<ingen matchar>";
$locale["Adjust"] =
   "Justera";
$locale["Calendar"] =
   "Kalender";
$locale["Cancel"] =
   "Avbyrt";
$locale["Complete."] =
   "Komplett.";
$locale["Contents"] =
   "Innehll";
$locale["Describe %s here."] =
   "Beskriv %s hr.";
$locale["Diff"] =
   "Diff";
$locale["Diff: %s"] =
   "Diff av: %s";
$locale["Edit"] =
   "Redigera";
$locale["Edit %s"] =
   "Redigera %s";
$locale["Edit: %s"] =
   "Redigera: %s";
$locale["EditText"] =
   "RedigeraText";
$locale["Empty pagename!"] =
   "Ange ett sidnamn!";
$locale["Fatal PhpWiki Error"] =
   "PhpWiki Fatal Error";
$locale["FindPage"] =
   "SkEfterSida";
$locale["Full text search results for '%s'"] =
   "Skresultat fr fulltextskning fr '%s'";
$locale["FullTextSearch"] =
   "Fulltextskning";
$locale["Go"] =
   "\"G till sidan\"";
$locale["GoodStyle"] =
   "BraStil";
$locale["H"] =
   "H";
$locale["Height"] =
   "Hjd";
$locale["Hits"] =
   "Trffar";
$locale["Hits:"] =
   "Trffar:";
$locale["HomePage"] =
   "Framsida";
$locale["Include of '%s' failed"] =
   "Insttning fr '%s' misslyckades";
$locale["Included from %s"] =
   "Insttning frn %s";
$locale["Last"] =
   "Senaste";
$locale["Last Author"] =
   "Gregende Frfattare";
$locale["Last Author:"] =
   "Gregende Frfattare:";
$locale["Last Modified"] =
   "ndringsdatum";
$locale["Last Modified:"] =
   "ndringsdatum:";
$locale["Last Summary"] =
   "Senaste Kommentar";
$locale["Last Summary:"] =
   "Senaste Kommentar:";
$locale["Last edited %s."] =
   "Senast ndrad %s.";
$locale["Last edited on %s."] =
   "Senast ndrad %s.";
$locale["Lock Page"] =
   "Ls Sida";
$locale["Locked"] =
   "Lst";
$locale["Modern"] =
   "Ny|modig";
$locale["MostPopular"] =
   "MestPopulr";
$locale["Next"] =
   "Nsta";
$locale["Next Month"] =
   "Fljande Mnad";
$locale["None"] =
   "Ingen";
$locale["Page Locked"] =
   "Sidan r Lst";
$locale["Page Name"] =
   "Namn p Sidan";
$locale["Preview"] =
   "versikt";
$locale["Previous"] =
   "Fregende";
$locale["Previous Author"] =
   "Gregende Frfattare";
$locale["Previous Month"] =
   "Fregende Mnad";
$locale["Printer"] =
   "Skrivare";
$locale["RecentChanges"] =
   "Senastendringar";
$locale["Remove Page"] =
   "Ta bort sida";
$locale["Remove page"] =
   "Ta bort sida";
$locale["Remove the page now"] =
   "Ta bort sida nu";
$locale["Removed page '%s' succesfully."] =
   "Tog bort sidan '%s'.";
$locale["Return to %s"] =
   "Tillbaka till %s";
$locale["Save"] =
   "Spara";
$locale["Saved: %s"] =
   "Sparade: %s";
$locale["Search"] =
   "Sk";
$locale["See %s tips for editing."] =
   "%s: Redigeringstips.";
$locale["Show relative dates using 'Today' and 'Yesterday'."] =
   "Andvnd relativt datum";
$locale["Sign In"] =
   "Anslut";
$locale["Sign Out"] =
   "Logga ut";
$locale["Sorry for the inconvenience."] =
   "Ledsen fr allt besvr.";
$locale["Synopsis"] =
   "versikt";
$locale["TextFormattingRules"] =
   "Textformateringsregler";
$locale["Thank you for editing %s."] =
   "Tack fr att du redigerade %s.";
$locale["The %d most popular pages of this wiki:"] =
   "De %d mest populra sidorna fr den hr wikin:";
$locale["The %d most recent %s are listed below."] =
   "De %d senaste %s sidorna listas nedan.";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Den hr sidan r lst av administratren och kan ej redigeras.";
$locale["Time Zone"] =
   "Timme Zon";
$locale["Title Search"] =
   "Titelskningen";
$locale["Title search results for '%s'"] =
   "Skresultat fr titelskningen fr '%s'";
$locale["TitleSearch"] =
   "Titelskningen";
$locale["Unlock Page"] =
   "Ls upp Sida";
$locale["UserId"] =
   "Namn";
$locale["Version"] =
   "Version";
$locale["Version %d"] =
   "Version %d";
$locale["Version %s, saved %s."] =
   "Version %s, sparade %s";
$locale["Version %s, saved on %s."] =
   "Version %s, sparade %s";
$locale["Versions are identical"] =
   "Versionerna r identiska";
$locale["View Source"] =
   "Visa Kllkoden";
$locale["View Source: %s"] =
   "Visa Kllkoden: %s";
$locale["W"] =
   "B";
$locale["Warning!"] =
   "Varning!";
$locale["Width"] =
   "Bredd";
$locale["You are about to remove '%s' permanently!"] =
   "Du kommer att ta bort \"%s\" permanent!";
$locale["Your careful attention to detail is much appreciated."] =
   "Din omstnksamhet fr detaljer r mycket uppskattad.";
$locale["by %s"] =
   "av %s";
$locale["current version"] =
   "nuvarande version";
$locale["diff"] =
   "diff";
$locale["from %s"] =
   "frn %s";
$locale["locked"] =
   "lst";
$locale["revision by previous author"] =
   "version frn fregende frfattare";
$locale["today"] =
   "i dag";
$locale["version %d"] =
   "version %d";
$locale["version %s"] =
   "version %s";
$locale["yesterday"] =
   "i gr";

?>

==> phpwiki_1.3.14.orig.tar.gz: phpwiki-1.3.14/locale/sv/LC_MESSAGES/phpwiki.php <==
<?php

$locale["%4d  %s\n"] =
   "%4d  %s\n";
$locale["%d best incoming links: "] =
   "De %d mest anvnda ingende lnkarna: ";
$locale["%d best outgoing links: "] =
   "De %d mest anvnda utgende lnkarna: ";
$locale["%d most popular nearby: "] =
   "De %d mest populra grannarna: ";
$locale["%s at %s"] =
   "%s i %s";
$locale["%s days"] =
   "%s dar";
$locale["%s of this page"] =
   "%s fr den hr sidan";
$locale["%s: %s"] =
   "%s: %s";
$locale["%s: file not found"] =
   "%s: fila ingen funna";
$locale["(diff)"] =
   "(diff)";
$locale["1 day"] =
   "1 dag";
$locale["<no matches>"] =
   "<ingen matchar>";
$locale["Adjust"] =
   "Justera";
$locale["Calendar"] =
   "Kalender";
$locale["Cancel"] =
   "Avbyrt";
$locale["Complete."] =
   "Komplett.";
$locale["Contents"] =
   "Innehll";
$locale["Describe %s here."] =
   "Beskriv %s hr.";
$locale["Diff"] =
   "Diff";
$locale["Diff: %s"] =
   "Diff av: %s";
$locale["Edit"] =
   "Redigera";
$locale["Edit %s"] =
   "Redigera %s";
$locale["Edit: %s"] =
   "Redigera: %s";
$locale["EditText"] =
   "RedigeraText";
$locale["Empty pagename!"] =
   "Ange ett sidnamn!";
$locale["Fatal PhpWiki Error"] =
   "PhpWiki Fatal Error";
$locale["FindPage"] =
   "SkEfterSida";
$locale["Full text search results for '%s'"] =
   "Skresultat fr fulltextskning fr '%s'";
$locale["FullTextSearch"] =
   "Fulltextskning";
$locale["Go"] =
   "\"G till sidan\"";
$locale["H"] =
   "H";
$locale["Height"] =
   "Hjd";
$locale["Hits"] =
   "Trffar";
$locale["Hits:"] =
   "Trffar:";
$locale["HomePage"] =
   "Framsida";
$locale["Included from %s"] =
   "Insttning frn %s";
$locale["Last"] =
   "Senaste";
$locale["Last Author"] =
   "Gregende Frfattare";
$locale["Last Modified"] =
   "ndringsdatum";
$locale["Last Summary"] =
   "Senaste Kommentar";
$locale["Last edited %s"] =
   "Senast ndrad %s";
$locale["Last edited on %s"] =
   "Senast ndrad %s";
$locale["Lock Page"] =
   "Ls Sida";
$locale["Locked"] =
   "Lst";
$locale["Modern"] =
   "Ny|modig";
$locale["MostPopular"] =
   "MestPopulr";
$locale["Next"] =
   "Nsta";
$locale["Next Month"] =
   "Fljande Mnad";
$locale["None"] =
   "Ingen";
$locale["Page Locked"] =
   "Sidan r Lst";
$locale["Page Name"] =
   "Namn p Sidan";
$locale["Preview"] =
   "versikt";
$locale["Previous"] =
   "Fregende";
$locale["Previous Author"] =
   "Gregende Frfattare";
$locale["Previous Month"] =
   "Fregende Mnad";
$locale["Printer"] =
   "Skrivare";
$locale["RecentChanges"] =
   "Senastendringar";
$locale["Remove Page"] =
   "Ta bort sida";
$locale["Removed page '%s' successfully."] =
   "Tog bort sidan '%s'.";
$locale["Return to %s"] =
   "Tillbaka till %s";
$locale["Save"] =
   "Spara";
$locale["Saved: %s"] =
   "Sparade: %s";
$locale["Search"] =
   "Sk";
$locale["See %s tips for editing."] =
   "%s: Redigeringstips.";
$locale["Sign In"] =
   "Anslut";
$locale["Sign Out"] =
   "Logga ut";
$locale["Sorry for the inconvenience."] =
   "Ledsen fr allt besvr.";
$locale["String \"%s\" not found."] =
   "\"%s\" ingen funna.";
$locale["Synopsis"] =
   "versikt";
$locale["Thank you for editing %s."] =
   "Tack fr att du redigerade %s.";
$locale["The %d most popular pages of this wiki:"] =
   "De %d mest populra sidorna fr den hr wikin:";
$locale["The %d most recent %s are listed below."] =
   "De %d senaste %s sidorna listas nedan.";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Den hr sidan r lst av administratren och kan ej redigeras.";
$locale["Time Zone"] =
   "Timme Zon";
$locale["Title Search"] =
   "Titelskningen";
$locale["Title search results for '%s'"] =
   "Skresultat fr titelskningen fr '%s'";
$locale["TitleSearch"] =
   "Titelskningen";
$locale["Unlock Page"] =
   "Ls upp Sida";
$locale["UserId"] =
   "Namn";
$locale["Version"] =
   "Version";
$locale["Version %d"] =
   "Version %d";
$locale["Version %s, saved %s"] =
   "Version %s, sparade %s";
$locale["Version %s, saved on %s"] =
   "Version %s, sparade %s";
$locale["Versions are identical"] =
   "Versionerna r identiska";
$locale["View Source"] =
   "Visa Kllkoden";
$locale["View Source: %s"] =
   "Visa Kllkoden: %s";
$locale["W"] =
   "B";
$locale["Width"] =
   "Bredd";
$locale["Your careful attention to detail is much appreciated."] =
   "Din omstnksamhet fr detaljer r mycket uppskattad.";
$locale["by %s"] =
   "av %s";
$locale["current version"] =
   "nuvarande version";
$locale["diff"] =
   "diff";
$locale["from %s"] =
   "frn %s";
$locale["locked"] =
   "lst";
$locale["revision by previous author"] =
   "version frn fregende frfattare";
$locale["today"] =
   "i dag";
$locale["version %d"] =
   "version %d";
$locale["version %s"] =
   "version %s";
$locale["yesterday"] =
   "i gr";

?>
